<script setup>
import { ref, nextTick, watch, defineProps } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';
import OrderDetlComponent from '@/components/orderDetl/edit.vue';

const formTable = ref(null);
const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {}
let formData = ref(initFormData);
const orderDetlChild = ref(null);

const props = defineProps({
    ioModel: 1
})

const emit = defineEmits(['tableReload'])

watch(open, async (newVal, oldVal) => {
    if (newVal) {
        await nextTick();// await dom update
        orderDetlChild.value.orderId = formData.value.id;
    }
})

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;

    let param = {
        orderNo: formData.value.orderNo,
        orderType: formData.value.orderType,
        orderSettle: formData.value.orderSettle,
        list: orderDetlChild.value.tableData
    }

    if (!isSave.value) {
        param.deleteDetlId = orderDetlChild.value.deleteDetlId;
        param.orderId = formData.value.id;
    }

    post(isSave.value ? '/api/order/save' : '/api/order/update', param).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(isSave.value ? formatMessage('page.add.success', '新增成功') : formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
        nextTick(() => {
            formTable.value.resetFields()
        })
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const orderTypeQueryList = ref(null);
orderTypeQuery();
function orderTypeQuery() {
    postForm('/api/orderType/query', {
        type: props.ioModel
    }).then(resp => {
        let result = resp.data;
        orderTypeQueryList.value = result.data;
    })
}
const orderSettleQueryList = ref(null);
orderSettleQuery();
function orderSettleQuery() {
    postForm('/api/orderSettle/query', {}).then(resp => {
        let result = resp.data;
        orderSettleQueryList.value = result.data;
    })
}
const userQueryList = ref(null);
userQuery();
function userQuery() {
    postForm('/api/user/query', {}).then(resp => {
        let result = resp.data;
        userQueryList.value = result.data;
    })
}

defineExpose({
    open,
    formData,
    initFormData,
    isSave,
})

</script>

<script>
export default {
    name: '订单-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 70%;">
            <a-form :model="formData" ref="formTable" name="formTable" :label-col="{ span: 2 }"
                :wrapper-col="{ span: 21 }" autocomplete="off" @finish="onFinish" @finishFailed="onFinishFailed">
                <a-form-item :label="formatMessage('db.man_order.order_no', '订单编号')" name="orderNo">
                    <a-input v-model:value="formData.orderNo" />
                </a-form-item>
                <!-- <a-form-item :label="formatMessage('db.man_order.order_time', '单据日期')" name="orderTime"
                    style="width: 250px;">
                    <a-input v-model:value="formData.orderTime" />
                </a-form-item> -->
                <a-form-item :label="formatMessage('db.man_order.order_type', '单据类型')" name="orderType">
                    <a-select v-model:value="formData.orderType" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="orderTypeQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_order.order_settle', '单据状态')" name="orderSettle">
                    <a-select v-model:value="formData.orderSettle" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="orderSettleQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <!-- <a-form-item :label="formatMessage('db.man_order.status', '状态')" name="status" >
                    <a-select v-model:value="formData.status" :options="[
                        { label: '正常', value: 1 },
                        { label: '禁用', value: 0 },
                    ]">
                    </a-select>
                </a-form-item> -->
                <!-- <a-form-item :label="formatMessage('db.man_order.create_time', '添加时间')" name="createTime"
                    style="width: 250px;">
                    <a-date-picker v-model:value="formData.createTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_order.create_by', '添加人员')" name="createBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.createBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="userQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_order.update_time', '修改时间')" name="updateTime"
                    style="width: 250px;">
                    <a-date-picker v-model:value="formData.updateTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_order.update_by', '修改人员')" name="updateBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.updateBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="userQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item> -->
                <!-- <a-form-item :label="formatMessage('db.man_order.memo', '备注')" name="memo" style="width: 250px;">
                    <a-input v-model:value="formData.memo" />
                </a-form-item> -->

                <a-form-item :label="formatMessage('db.man_order.update_time', '订单明细')" name="orderDetl">
                    <OrderDetlComponent ref="orderDetlChild" />
                </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>

        </a-modal>
    </div>
</template>

<style></style>
